AutoGainEnum enum
Values
- targetRms → const AutoGainEnum
- attackTime → const AutoGainEnum
- releaseTime → const AutoGainEnum
- gainSmoothing → const AutoGainEnum
- maxGain → const AutoGainEnum
- minGain → const AutoGainEnum
- noiseFloorDb → const AutoGainEnum
- headroomDb → const AutoGainEnum
- currentGain → const AutoGainEnum
- inputRms → const AutoGainEnum
- outputPeak → const AutoGainEnum
- limiterClipCount → const AutoGainEnum
- totalLimiterClipCount → const AutoGainEnum
- lastFrameCount → const AutoGainEnum
Properties
- def → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isWritable → bool
-
no setter
- max → double
-
no setter
- min → double
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AutoGainEnum> - A constant List of the values in this enum, in order of their declaration.