toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => switch (this) {
      AutoGainEnum.targetRms => 'Target RMS',
      AutoGainEnum.attackTime => 'Attack Time',
      AutoGainEnum.releaseTime => 'Release Time',
      AutoGainEnum.gainSmoothing => 'Gain Smoothing',
      AutoGainEnum.maxGain => 'Max Gain',
      AutoGainEnum.minGain => 'Min Gain',
      AutoGainEnum.noiseFloorDb => 'Noise Floor dB',
      AutoGainEnum.headroomDb => 'Headroom dB',
      AutoGainEnum.currentGain => 'Current Gain',
      AutoGainEnum.inputRms => 'Input RMS',
      AutoGainEnum.outputPeak => 'Output Peak',
      AutoGainEnum.limiterClipCount => 'Limiter Clip Count',
      AutoGainEnum.totalLimiterClipCount => 'Total Limiter Clip Count',
      AutoGainEnum.lastFrameCount => 'Last Frame Count',
    };