flutter_recorder library
Flutter low level audio recorder plugin using miniaudio library and FFI
Classes
- AudioDataContainer
- Class that contain the streamed audio data.
- AutoGain
- CaptureDevice
- CaptureDevice exposed to Dart
- EchoCancellation
- FilterMetric
- Read-only runtime value exposed by a filter.
- FilterParam
- Common class for single and global filters.
- Recorder
- Use this class to capture audio (such as from a microphone).
Enums
- AndroidInputPreset
- Android capture input presets.
- AutoGainEnum
- CaptureErrors
- Possible capture errors
- EchoCancellationEnum
- PCMFormat
- The PCM format
- RecorderChannels
- The channels to be used while initializing the player.
- RecorderFilterType
- The different types of audio filters.
- RecordingFormat
- The format used when recording to a file.
- StreamingFormat
- The format used when streaming audio data.
Typedefs
- SilenceCallback = void Function(bool isSilent, double decibel)
- Callback when silence state is changed.
- SilenceState = ({double decibel, bool isSilent})
- Silence state.