StreamingFormat enum
The format used when streaming audio data.
Values
- pcm → const StreamingFormat
-
Raw PCM data.
const StreamingFormat(0) - opus → const StreamingFormat
-
Opus packets. Each packet is length-prefixed with a 4-byte little-endian integer.
const StreamingFormat(1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Internal value passed to the native recorder.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → StreamingFormat
Constants
-
values
→ const List<
StreamingFormat> - A constant List of the values in this enum, in order of their declaration.